# auth

## Module: {mod}`zmq.auth`

```{eval-rst}
.. automodule:: zmq.auth
```

```{currentmodule} zmq.auth
```

## {class}`Authenticator`

```{eval-rst}
.. autoclass:: Authenticator
  :members:
  :undoc-members:
  :inherited-members:

```

## Functions

```{eval-rst}
.. autofunction:: create_certificates
```

```{eval-rst}
.. autofunction:: load_certificate
```

```{eval-rst}
.. autofunction:: load_certificates
```
